// Util functions
// Copyright 2013, 2014 by John K. Hinsdale.  See LICENSE.html for terms of use.

// Does string equal another (case-insensitive)
function equals(s, targ) {
    return s.toLowerCase() == targ.toLowerCase();
}

// Does string contain another (case-insensitive)
function contains(s, targ) {
    return s.toLowerCase().indexOf(targ.toLowerCase()) != -1;
}

// Does string start with another (case-insensitive)
function starts_with(str, leader) {
    return str.toLowerCase().indexOf(leader.toLowerCase()) == 0;
}

// Does string end with another
function ends_with(str, suffix) {
    var strlen = str.length;
    var sufflen = suffix.length;
    return str.toLowerCase().indexOf(suffix.toLowerCase(), strlen - sufflen) != -1;
}

// Does string match regex
function re_matches(s, expr) {
    return s.match(new RegExp(expr, 'i'));
}

// Functions to match a list of targets on implied "or" basis
function match_list_starts(s, lst) {
    for (var i=0; i < lst.length; i++)
        if ( starts_with(s, lst[i]) )
            return true;
    return false;
}
function match_list_ends(s, lst) {
    for (var i=0; i < lst.length; i++)
        if ( ends_with(s, lst[i]) )
            return true;
    return false;
}
function match_list_equals(s, lst) {
    for (var i=0; i < lst.length; i++)
        if ( equals(s, lst[i]) )
            return true;
    return false;
}
function match_list_contains(s, lst) {
    for (var i=0; i < lst.length; i++)
        if ( contains(s, lst[i]) )
            return true;
    return false;
}
function match_list_matches(s, lst) {
    for (var i=0; i < lst.length; i++)
        if ( re_matches(s, lst[i]) )
            return true;
    return false;
}

// Pad string on right to length
function pad(s, n) {
    while ( s.length < n )
        s += " ";
    return s;
}

// Array to hash whose keys are elements of array and all map to val
function array_to_hash(arr, val) {
    var n = arr.length;
    var result = {};
    for(var i=0; i<n; i++)
        result[arr[i]] = val;
    return result;
}

// Format hash as string for debugging
function hash_to_string(h) {
    var s = ""
    for ( var k in h ) {
        if ( s != "" )
            s += " | ";
        s += "'" + k + "' => '" + h[k] + "'";
    }
    return s;
}

// Escape regex chars in string so it can be used as a literal
function re_escape(s) {
    return s.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
}

// Global string replace, using regex, case SENSITIVE
function replace_all(s, from, to) {
    return s.replace(new RegExp(re_escape(from), 'g'), to);
}

// Deep clone an object (functions will be lost)
function deep_clone (ob) {
    // Just run it through JSON
    return JSON.parse(JSON.stringify(ob));
}

// Is value an array?
function is_array(val) {
    // Note that "(val instanceof Array)" does NOT work here
    return Array.isArray(val) || (Object.prototype.toString.call(val) == '[object Array]');
}

// Get regex, given string.  Return hash with:
//    re_str: input string given
//    valid: true, in which case "regex" contains the regex object
//    valid: false, in which case "error" contains message
// Flags "g" and "i" are always given
function get_regex(s) {
    var result = { valid: false, re_str: s };
    var re;
    try {
        var re = new RegExp(s, "gi");
        result.regex = re;
        result.valid = true;
    }
    catch (exc) {
        result.error = exc.toString();
    }
    return result;
}
// $Id: util.js,v 1.9 2014/12/23 12:38:42 hin Exp $
